# Installation

## Stable release

To install dj-notify, run this command in your terminal:

```sh
pip install dj_notify
```

This is the preferred method to install dj-notify, as it will always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

## From sources

The sources for dj-notify can be downloaded from the [Github repo](https://github.com/audreyfeldroy/dj_notify).

You can either clone the public repository:

```sh
git clone git://github.com/audreyfeldroy/dj_notify
```

Or download the [tarball](https://github.com/audreyfeldroy/dj_notify/tarball/master):

```sh
curl -OJL https://github.com/audreyfeldroy/dj_notify/tarball/master
```

Once you have a copy of the source, you can install it with:

```sh
python setup.py install
```
